// WinceDll.h : WinceDll DLL 的主头文件
//



#ifndef _WINCEDLL_H
#define _WINCEDLL_H


////打开通信串口  1: COMM1 2:COMM2 ....
extern "C" _declspec(dllexport) int OpenPort(int iPort);

///关闭通信口
extern "C" _declspec(dllexport) void ClosePort();

///往串口送数
extern "C" _declspec(dllexport) int WriteData(unsigned char *pData,int len);


////从串口读数
extern "C" _declspec(dllexport) int ReadData(unsigned char *pData,int len);

///从打印机取状态 ， 对应命令DLE EOT n   iParam = 1 ,2 ,3, 4
extern "C" _declspec(dllexport) int GetStatus(int iParam);

///切纸
extern "C" _declspec(dllexport) int CutPaper();

/// 走纸 iMm 毫米
extern "C" _declspec(dllexport) int FeedPaper(int iMm);

////在xpos, ypos 点，打印字符串，不能往反方向打印，只能往前打印字符，打印头只能往前，从上到下，从左到右
extern "C" _declspec(dllexport) int PrintString(int xpos, int ypos, char* str, int len);


#endif